#
# spec file for package libfido2
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover  1_0_0
Name:           libfido2
Version:        1.0.0
Release:        lp152.2.8
Summary:        FIDO U2F and FIDO 2.0 protocols
License:        BSD-2-Clause
Group:          Productivity/Networking/Security
URL:            https://developers.yubico.com/
Source0:        https://developers.yubico.com/libfido2/Releases/%{name}-%{version}.tar.gz
Source1:        https://developers.yubico.com/libfido2/Releases/%{name}-%{version}.tar.gz.sig
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libhidapi-devel
BuildRequires:  libopenssl-1_1-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libcbor)

%description
Provides library functionality for communicating with a FIDO device
over USB as well as verifying attestation and assertion signatures.

%package     -n %{name}-%{sover}
Summary:        FIDO U2F and FIDO 2.0 protocols
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n %{name}-%{sover}
This library supports the FIDO U2F and FIDO 2.0 protocols for
communicating with a USB authenticator via the
Client-to-Authenticator Protocol (CTAP 1 and 2).

%package     -n %{name}-devel
Summary:        Development files for FIDO U2F and FIDO 2.0 protocols
Group:          Development/Libraries/C and C++
Requires:       %{name}-%{sover} = %{version}
Requires:       libhidapi-devel
Requires:       libopenssl-1_1-devel

%description -n %{name}-devel
This package contains the header file needed to develop applications that
use FIDO U2F and FIDO 2.0 protocols.

%prep
%setup -q

%build
%cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} -DCBOR_LIBRARY_DIRS=%{_libdir} -DCMAKE_BUILD_TYPE=Release
make %{?_smp_mflags}

%install
pushd build
%make_install
popd
find %{buildroot} -type f -name "*.a" -delete -print

%post   -n %{name}-%{sover} -p /sbin/ldconfig
%postun -n %{name}-%{sover} -p /sbin/ldconfig

%files -n %{name}-%{sover}
%license LICENSE
%doc README.adoc
%{_libdir}/%{name}.so.*
%{_mandir}/man?/*
%{_bindir}/fido2-*

%files -n %{name}-devel
%{_includedir}/*.h
%dir %{_includedir}/fido
%{_includedir}/fido/*.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/*

%changelog
* Thu Mar 21 2019 Karol Babioch <kbabioch@suse.de>
- Version 1.0.0 (released 2019-03-21)
  * Native HID support on Linux, MacOS, and Windows.
  * fido2-{assert,cred}: new -u option to force U2F on dual authenticators.
  * fido2-assert: support for multiple resident keys with the same RP.
  * Strict checks for CTAP2 compliance on received CBOR payloads.
  * Better fuzzing harnesses.
  * Documentation and reliability fixes.
* Wed Jan  9 2019 Karol Babioch <kbabioch@suse.de>
- Version 0.4.0 (released 2019-01-07)
  * fido2-assert: print the user id for resident credentials.
  * Fix encoding of COSE algorithms when making a credential.
  * Rework purpose of fido_cred_set_type; no ABI change.
  * Minor documentation and code fixes.
- Dropped patch that is included upstream now: fix-release-build.patch
* Mon Oct  1 2018 Karol Babioch <kbabioch@suse.com>
- Added patch:
  * fix-release-build.patch: Disables regression tests as proposed by upstream
* Mon Oct  1 2018 Karol Babioch <kbabioch@suse.com>
- Applied spec-cleaner
* Sun Sep 30 2018 t.gruner@katodev.de
- Build package without regression tests
- Version 0.3.0 (released 2018-09-11)
  - Various reliability fixes.
  - Merged fuzzing instrumentation.
  - Added regress tests.
  - Added support for FIDO 2’s hmac-secret extension.
  - New API calls:
  * fido_assert_hmac_secret_len;
  * fido_assert_hmac_secret_ptr;
  * fido_assert_set_extensions;
  * fido_assert_set_hmac_salt;
  * fido_cred_set_extensions;
  * fido_dev_force_fido2.
  - Support for native builds with Microsoft Visual Studio 17.
* Fri Sep 28 2018 Jan Engelhardt <jengelh@inai.de>
- Fix RPM group. Wrap description.
* Thu Jun 21 2018 t.gruner@katodev.de
- Version 0.2.0 (released 2018-06-20)
  - Added command-line tools.
  - Added a couple of missing get functions.
- Version 0.1.1 (released 2018-06-05)
  - Added documentation.
  - Added OpenSSL 1.0 support.
  - Minor fixes.
* Sun May 27 2018 t.gruner@katodev.de
- update to version 0.1.0
* Mon Apr 30 2018 t.gruner@katodev.de
- Initial release version 0_git
